@@ -1,14 +1,16 @@
-## general mediawiki-engine (Web)
-#
-# @website     websites built on mediawiki (https://www.mediawiki.org)
-# @provide-api yes (http://www.mediawiki.org/wiki/API:Search)
-#
-# @using-api   yes
-# @results     JSON
-# @stable      yes
-# @parse       url, title
-#
-# @todo        content
+"""
+ general mediawiki-engine (Web)
+
+ @website     websites built on mediawiki (https://www.mediawiki.org)
+ @provide-api yes (http://www.mediawiki.org/wiki/API:Search)
+
+ @using-api   yes
+ @results     JSON
+ @stable      yes
+ @parse       url, title
+
+ @todo        content
+"""
 
 from json import loads
 from string import Formatter
@@ -22,13 +24,13 @@ number_of_results = 1
 
 # search-url
 base_url = 'https://{language}.wikipedia.org/'
-search_url = base_url + 'w/api.php?action=query'\
-                                 '&list=search'\
-                                 '&{query}'\
-                                 '&srprop=timestamp'\
-                                 '&format=json'\
-                                 '&sroffset={offset}'\
-                                 '&srlimit={limit}'     # noqa
+search_postfix = 'w/api.php?action=query'\
+    '&list=search'\
+    '&{query}'\
+    '&format=json'\
+    '&sroffset={offset}'\
+    '&srlimit={limit}'\
+    '&srwhat=nearmatch'  # search for a near match in the title
 
 
 # do search-request
@@ -44,14 +46,17 @@ def request(query, params):
     if params['language'] == 'all':
         language = 'en'
     else:
-        language = params['language'].split('_')[0]
+        language = params['language'].split('-')[0]
 
-    if len(format_strings) > 1:
+    # format_string [('https://', 'language', '', None), ('.wikipedia.org/', None, None, None)]
+    if any(x[1] == 'language' for x in format_strings):
         string_args['language'] = language
 
     # write search-language back to params, required in response
     params['language'] = language
 
+    search_url = base_url + search_postfix
+
     params['url'] = search_url.format(**string_args)
 
     return params
@@ -69,6 +74,8 @@ def response(resp):
 
     # parse results
     for result in search_results['query']['search']:
+        if result.get('snippet', '').startswith('#REDIRECT'):
+            continue
         url = base_url.format(language=resp.search_params['language']) +\
             'wiki/' + quote(result['title'].replace(' ', '_').encode('utf-8'))
 
