@@ -1,12 +1,14 @@
-## OpenStreetMap (Map)
-#
-# @website     https://openstreetmap.org/
-# @provide-api yes (http://wiki.openstreetmap.org/wiki/Nominatim)
-#
-# @using-api   yes
-# @results     JSON
-# @stable      yes
-# @parse       url, title
+"""
+ OpenStreetMap (Map)
+
+ @website     https://openstreetmap.org/
+ @provide-api yes (http://wiki.openstreetmap.org/wiki/Nominatim)
+
+ @using-api   yes
+ @results     JSON
+ @stable      yes
+ @parse       url, title
+"""
 
 from json import loads
 from searx.utils import searx_useragent
@@ -38,7 +40,10 @@ def response(resp):
 
     # parse results
     for r in json:
-        title = r['display_name']
+        if 'display_name' not in r:
+            continue
+
+        title = r['display_name'] or u''
         osm_type = r.get('osm_type', r.get('type'))
         url = result_base_url.format(osm_type=osm_type,
                                      osm_id=r['osm_id'])
@@ -49,10 +54,8 @@ def response(resp):
         geojson = r.get('geojson')
 
         # if no geojson is found and osm_type is a node, add geojson Point
-        if not geojson and\
-           osm_type == 'node':
-            geojson = {u'type': u'Point',
-                       u'coordinates': [r['lon'], r['lat']]}
+        if not geojson and osm_type == 'node':
+            geojson = {u'type': u'Point', u'coordinates': [r['lon'], r['lat']]}
 
         address_raw = r.get('address')
         address = {}
